@@ -11,6 +11,16 @@ from Crypto.Cipher import AES as _AES_
 from Crypto import Random
 from Crypto.Protocol.KDF import PBKDF2
 
+# unpack format & encrypted.
+def unpack(content):
+	if " " not in content:
+		raise ValueError("Encrypted format is incorrectly packed.")
+	format = ""
+	for i in content:
+		if i not in [" "]: format += i
+		else: break
+	return format, content[len(format):]
+
 # the symetric aes 254 object class.
 class AES(object):
 	def __init__(self, passphrase=None):
@@ -145,7 +155,7 @@ class AsymmetricAES(object):
 		if isinstance(string, bytes):
 			string = string.decode()
 		try:
-			key,encrypted = string.split(" ")
+			key,encrypted = unpack(string)
 		#except:
 		except KeyboardInterrupt:
 			return r3sponse.error("Unable to unpack the encrypted data.")
@@ -494,14 +504,6 @@ class Database(object):
 			return r3sponse.success(f"Successfully checked the content of {self.path}.")
 		# load & decrypt.
 		def load(self):
-			def unpack(content):
-				if " " not in content:
-					raise ValueError("Encrypted format is incorrectly packed.")
-				format = ""
-				for i in content:
-					if i not in [" "]: format += i
-					else: break
-				return format, content[len(format):]
 			try:
 				format, content = unpack(Files.load(self.path))
 			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
